#
#
# system - system related classes & functions
#
# (c) 2022 - 2023  Mike Knerr
#
#

## other promordal classes

from .object import Object
import os

class System(Object):
    # so far just a wrapper for some 
    # common shell commands from underlying OS/HW system
    # not the robots interface shell yet

    def __init__(self): #v0.07
        super(System, self).__init__()
         
        self._name = "System"
        self._desc = "OS/HW System shell functions"
        self._vers = "v0.01.01a"  
        self._model = ""
        
    def kernelVersion(self):
        # not a get, not return string
        os.system('uname -r')
    
    def kernelVers(self):
        self.kernelVersion()
        
    def distroVersion(self):
        os.system('lsb_release -a')
    
    def distroVers(self):
        return self.distroVersion()
    
    def kernel(self):
        return self.kernelVers()
    
    def distro(self):
        return self.distroVers()
    
    def command(self,cmd):
        return os.system(cmd)
    
    def cmd(self,cmd):
        return self.command(cmd)
    



#
#
# Object - primary primordal base class 
#
# (c) 2022 - 2024  Mike Knerr
#
#

import os 

class Object(object): 
     ## primordal class
     def __init__(self): 
         self._id = id(self) #dont override ever
         self._debug_flag = False
         # successive classes override these in init
         self._name="Object"
         self._desc="Object - Primary Base Object"
         self._vers="v0.01.08" # not pypi vers
         self._model = "" # more for derived classes
         self._about="About Object..."
         self._instance_name = ""
         
     # who ##
     def whoami(self):
         print(self._name,self._vers,self._model)

     def getWhoami(self):
         # space sep for now
         return str(self._name+" "+self._vers)
         #return str(self._name+" "+self._vers+" "+self._model)
                   
     def whoamiStr(self):
         return self.getWhoami()
     
#    def whoami(self):
#          if len(self._model) > 0:
#           print(self._name + " - " + self._vers +" - "+ self._model) 
#          else:
#           print(self._name + " - " + self._vers)

     # get ##
     
     def getId(self):
         return self._id
     
     def getName(self):
        return self._name

     def getDesc(self):
        return self._desc
    
     def getVersion(self):
        return self._vers
    
     def getVers(self):
        return self._vers
    
     def getAbout(self):
        return self._about
    
     def getModel(self):
        return self._model
        
     # set ##
     
     def setName(self,n):
         self._name = n
    
     def setDesc(self,d):
         self._desc = d
         
     def setAbout(self,a):
         self._about = a
    
     def setModel(self,m):
        self._model = m
    
     # not on the public inteface
     # hard code this one in derived classes
     # def setVers(self,v):
     #    self._vers =v
     
     # shell commands ##
     
     def id(self):
         print(self._id)
         
     def name(self):
          print(self._name)

     def desc(self):
          print(self._desc)
    
     def version(self):
          print(self._vers)
    
     def vers(self):
          print(self._vers)
    
     def about(self):
          print(self._about)
    
     def model(self):
          print(self._model)
          
     # debug ##   
     
     def setDebugOn(self):
         self._debug_flag = True
         
     def setDebugOff(self):
         self._debug_flag = False

     def debug(self):
         return (self._debug_flag == True) 
         
     def debugIsOn(self):
         # makes more sense w/ if debugIsOn(): then...
         return (self._debug_flag == True) #test as bool
       
     def isDebugOn(self):
         # backward compat
         return self.debugIsOn()
          
     #future rem these 2 use set*()
     #def debugOn(self):
     #    self.setDebugOn()
     
     #def debugOff(self):
     #    self.setDebugOff()
        
    




#! /usr/bin/env python

from setuptools import Command, Extension, setup
from setuptools.command.build_ext import build_ext


DISTNAME = "robo-base"
#DESCRIPTION = "primary base object"

if __name__ == "__main__":
    setup()
 
#mk  works

import robobase

#import robo_base as robobase

#


